### test boundaries
cL<- 1.5
cU<- 1.5
alphaL<-0.025
alphaU<-0.05   ### asymmetric CI boundaries

### pop values
muR<-0
sigR<-1
sigB<-sqrt(1)
muB<- muR-cL*sigR  ### lower null value
#muB<- muR+cU*sigR  ### upper null value
lambda<-(muB-muR)/sigR

### sample sizes
nB<-10
nR<-15
df<-nB+nR-2
nconst<-sqrt(1/nB + 1/nR)

### R code to reproduce function tnonct in SAS
f <- function(delta, pr, x, df) pt(x, df = df, ncp = delta) - pr
tnonct<-function(alpha,tcalc,df){
	out<-try(uniroot(f, c(tcalc-5, tcalc+5), pr = alpha, x = tcalc, check.conv=TRUE, 
							 df = df), silent=TRUE) ### 37.62 numerical limit for ncp in R function pt
	if(class(out)!="list")return(NA) else return(out$root) 
}


set.seed(12357)
nrep<-100000 
decTOST<-rep(NA,nrep)
decCI<-rep(NA,nrep)
for(i in 1:nrep){
	xR<-rnorm(nR,muR,sigR)
	xB<-rnorm(nB,muB,sigB)
	xbarR<-mean(xR)
	xbarB<-mean(xB)
	xsdR<-sd(xR)
	xsdB<-sd(xB)		
	xsdp<-sqrt( ((nB-1)*xsdB^2+(nR-1)*xsdR^2)/(nB+nR-2) )
	lamhat<-(xbarB-xbarR)/xsdp
	tcalc<-lamhat/nconst
	
	### TOST decision criteria
	ncp<- cU/nconst
	pvalup<-pt(tcalc,ncp=ncp,df)
	ncp<- -cL/sqrt(1/nB + 1/nR)
	pvallow<-1-pt(tcalc,ncp=ncp,df)
	decTOST[i]<- (pvalup<=alphaU) && (pvallow<=alphaL)
	
	### Equivalent CI based decision criteria  
	ncplow<-tnonct(1-alphaL,tcalc,df)
	ncpup<-tnonct(alphaU,tcalc,df)	
	
	lamlow<-nconst*ncplow
	lamup<-nconst*ncpup
	decCI[i]<- (lamlow >= -cL) && (lamup <= cU)
	}	
	



### two one-sided tests of lambda>=1.5 and lambda<=-1.5
### accept equivalence if both test reject with pvals<=alpha
mean(decTOST,na.rm=TRUE)
mean(decCI,na.rm=TRUE)

### how often do the intervals and tost disagree
sum(decTOST!=decCI,na.rm=TRUE)

### how many numerical failures in each approach
### note also warning messages when extreme ncp values are evaluated
### the implementation of tnonct here is primitive and may need 
### adjustment for more extreme condtions
sum(is.na(decTOST))
sum(is.na(decCI))



